[vlc-devel] commit: input: Support file://localhost/file type url. (Pierre d'Herbemont )

git version control git at videolan.org
Mon Jun 29 05:20:27 CEST 2009


vlc | branch: master | Pierre d'Herbemont <pdherbemont at free.fr> | Sun Jun 28 20:18:17 2009 -0700| [16f6bf947e9977eb540c599f462a66cd7d2a96a0] | committer: Pierre d'Herbemont 

input: Support file://localhost/file type url.

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=16f6bf947e9977eb540c599f462a66cd7d2a96a0
---

 src/input/input.c |   18 ++++++++++++------
 1 files changed, 12 insertions(+), 6 deletions(-)

diff --git a/src/input/input.c b/src/input/input.c
index 6bbaba8..d9133b1 100644
--- a/src/input/input.c
+++ b/src/input/input.c
@@ -2358,12 +2358,18 @@ static int InputSourceInit( input_thread_t *p_input,
             && psz_path[0] != DIR_SEP_CHAR
 #endif
           )
-        {   /* host specified -> not supported currently */
-            msg_Err( p_input, "cannot open remote file `%s://%s'",
-                     psz_access, psz_path );
-            msg_Info( p_input, "Did you mean `%s:///%s'?",
-                      psz_access, psz_path );
-            goto error;
+        {   /* host specified -> only localhost is supported */
+            static const unsigned localhostLen = 9; /* strlen("localhost") */
+            if (!strncmp( psz_path, "localhost" DIR_SEP, localhostLen + 1))
+                psz_path += localhostLen;
+            else
+            {
+                msg_Err( p_input, "cannot open remote file `%s://%s'",
+                        psz_access, psz_path );
+                msg_Info( p_input, "Did you mean `%s:///%s'?",
+                         psz_access, psz_path );
+                goto error;
+            }
         }
         /* Remove HTML anchor if present (not supported). */
         char *p = strchr( psz_path, '#' );




More information about the vlc-devel mailing list